@@ -1,4 +1,4 @@
 package perlsecret;
-use strict;    # make CPANT happy
-our $VERSION = '1.004';
+use strict;    # make CPANTS happy
+our $VERSION = '1.005';
 0;    # no point in loading this module
